"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const cli_ux_1 = tslib_1.__importDefault(require("cli-ux"));
const root_command_1 = tslib_1.__importDefault(require("../../root-command"));
class ServiceStop extends root_command_1.default {
    async run() {
        const { argv, flags } = this.parse(ServiceStop);
        if (flags['delete-data'] && !flags.confirm) {
            cli_ux_1.default.warn('This will delete all data associated to this instance');
            if (!await cli_ux_1.default.confirm('Are you sure?'))
                return [];
        }
        this.spinner.start('Delete instance');
        for (const hash of argv) {
            this.spinner.status = hash;
            await this.api.instance.delete({ hash, deleteData: flags['delete-data'] });
        }
        this.spinner.stop(argv.join(', '));
        return argv;
    }
}
ServiceStop.description = 'Stop a service by deleting a specific instance';
ServiceStop.flags = Object.assign({}, root_command_1.default.flags, { 'delete-data': command_1.flags.boolean({
        description: 'Delete instances\' persistent data',
        default: false,
    }), confirm: command_1.flags.boolean({
        description: 'Confirm delete',
        default: false,
        dependsOn: ['delete-data']
    }) });
ServiceStop.strict = false;
ServiceStop.args = [{
        name: 'INSTANCE_HASH',
        required: true,
    }];
exports.default = ServiceStop;
